mbed library sources. Supersedes mbed-src.

Dependents:   Nucleo_Hello_Encoder BLE_iBeaconScan AM1805_DEMO DISCO-F429ZI_ExportTemplate1 ... more

Revision:
167:e84263d55307
Parent:
149:156823d33999
Child:
168:9672193075cf
--- a/drivers/TimerEvent.h	Thu Jun 08 15:02:37 2017 +0100
+++ b/drivers/TimerEvent.h	Wed Jun 21 17:46:44 2017 +0100
@@ -21,11 +21,11 @@
 
 namespace mbed {
 /** \addtogroup drivers */
-/** @{*/
 
 /** Base abstraction for timer interrupts
  *
- * @Note Synchronization level: Interrupt safe
+ * @note Synchronization level: Interrupt safe
+ * @ingroup drivers
  */
 class TimerEvent {
 public:
@@ -33,6 +33,8 @@
     TimerEvent(const ticker_data_t *data);
 
     /** The handler registered with the underlying timer interrupt
+     *
+     *  @param id       Timer Event ID
      */
     static void irq(uint32_t id);
 
@@ -44,9 +46,12 @@
     // The handler called to service the timer event of the derived class
     virtual void handler() = 0;
 
     // insert in to linked list
     void insert(timestamp_t timestamp);
 
+    // insert absolute timestamp into linked list
+    void insert_absolute(us_timestamp_t timestamp);
+
     // remove from linked list, if in it
     void remove();
 
@@ -58,5 +63,3 @@
 } // namespace mbed
 
 #endif
-
-/** @}*/
@@ -44,9 +46,12 @@
     virtual void handler() = 0;
 
-    // insert in to linked list
+    // insert relative timestamp in to linked list
     void insert(timestamp_t timestamp);
 